Description Usage Arguments Value Examples
Algorithm for kmeans clustering of numeric matrix of data
1 | k_means_cluster(x, k, tolerance = 1e-5, nstart = 9)
|
x |
A numeric matrix of data |
k |
A number of clusters; note that only when x>>k will k-means be robust. |
tolerance |
A tolerance number that determines whether the centroids are converge, default is 1e-5 |
nstart |
An iteration number since k-means clustering depends on the initial centroids, default is 9 |
The original data matrix x, a vector of the clusters, a matrix of the coordinates of k centroids
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.